==> 1.0.0.tar.gz: lib/src/widgets/single/FilterSingleWithProfileIten.dart <==
part of modern_form_filter;

class FilterSingleWithProfileIten extends StatelessWidget {
  final String? bottomSheetLabelText;
  final String? buttonText;
  final void Function()? onRemove;
  final ModernFormBottomSheetProfileModel? initialValue;
  final void Function()? onTap;
  final void Function(BuildContext context)? onTapWithContext;

  const FilterSingleWithProfileIten({
    Key? key,
    this.bottomSheetLabelText,
    this.buttonText,
    this.onRemove,
    this.initialValue,
    this.onTap,
    this.onTapWithContext,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool exist = initialValue!.name != null && initialValue!.name!.isNotEmpty;

    return Column(
      children: <Widget>[
        Padding(
          padding: EdgeInsets.only(
              top: ScreenUtil().setSp(8), left: ScreenUtil().setSp(10)),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              exist
                  ? Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        FilterProfileIten(
                          title: exist ? initialValue!.name : "",
                          subTitle: initialValue?.description ?? "",
                          image: initialValue?.imageUrl ?? "",
                        ),
                        IconButton(
                          icon: Icon(Icons.close, size: ScreenUtil().setSp(20)),
                          onPressed: onRemove,
                        )
                      ],
                    )
                  : SizedBox(),
              SizedBox(height: ScreenUtil().setSp(7)),
              Builder(
                builder: (context) => ElevatedButton(
                  child: Text(buttonText ?? ""),
                  onPressed: onTap != null || onTapWithContext != null
                      ? () {
                          if (onTap != null) {
                            onTap!();
                          } else {
                            onTapWithContext!(context);
                          }
                        }
                      : null,
                ),
              ),
            ],
          ),
        ),
      ],
    );
  }
}

==> 1.0.1.tar.gz: lib/src/widgets/single/FilterSingleWithProfileIten.dart <==
part of modern_form_filter;

class FilterSingleWithProfileIten extends StatelessWidget {
  final String? bottomSheetLabelText;
  final String? buttonText;
  final void Function()? onRemove;
  final ModernFormBottomSheetProfileModel? initialValue;
  final void Function()? onTap;
  final void Function(BuildContext context)? onTapWithContext;

  const FilterSingleWithProfileIten({
    Key? key,
    this.bottomSheetLabelText,
    this.buttonText,
    this.onRemove,
    this.initialValue,
    this.onTap,
    this.onTapWithContext,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool exist = initialValue!.name != null && initialValue!.name!.isNotEmpty;

    return Column(
      children: <Widget>[
        Padding(
          padding: EdgeInsets.only(
              top: ScreenUtil().setSp(8), left: ScreenUtil().setSp(10)),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              exist
                  ? Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        ModernFormFilterProfileIten(
                          label: exist ? initialValue!.name : "",
                          subTitle: initialValue?.description ?? "",
                          image: initialValue?.imageUrl ?? "",
                        ),
                        IconButton(
                          icon: Icon(Icons.close, size: ScreenUtil().setSp(20)),
                          onPressed: onRemove,
                        )
                      ],
                    )
                  : SizedBox(),
              SizedBox(height: ScreenUtil().setSp(7)),
              Builder(
                builder: (context) => ElevatedButton(
                  child: Text(buttonText ?? ""),
                  onPressed: onTap != null || onTapWithContext != null
                      ? () {
                          if (onTap != null) {
                            onTap!();
                          } else {
                            onTapWithContext!(context);
                          }
                        }
                      : null,
                ),
              ),
            ],
          ),
        ),
      ],
    );
  }
}
